@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Type, Union
+from typing import IO, Any, Dict, Mapping, Sequence, Type, Union
 
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
@@ -63,7 +63,7 @@ __all__ = ("CodeGuruProfilerClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -80,7 +80,7 @@ class Exceptions:
 
 class CodeGuruProfilerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html)
     """
 
@@ -93,12 +93,12 @@ class CodeGuruProfilerClient(BaseClient):
         """
 
     def add_notification_channels(
-        self, *, channels: List["ChannelTypeDef"], profilingGroupName: str
+        self, *, channels: Sequence["ChannelTypeDef"], profilingGroupName: str
     ) -> AddNotificationChannelsResponseTypeDef:
         """
         Add up to 2 anomaly notifications channels for a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.add_notification_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.add_notification_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#add_notification_channels)
         """
 
@@ -106,17 +106,17 @@ class CodeGuruProfilerClient(BaseClient):
         self,
         *,
         profilingGroupName: str,
-        endTime: Union[datetime, str] = None,
-        frameMetrics: List["FrameMetricTypeDef"] = None,
-        period: str = None,
-        startTime: Union[datetime, str] = None,
-        targetResolution: AggregationPeriodType = None
+        endTime: Union[datetime, str] = ...,
+        frameMetrics: Sequence["FrameMetricTypeDef"] = ...,
+        period: str = ...,
+        startTime: Union[datetime, str] = ...,
+        targetResolution: AggregationPeriodType = ...
     ) -> BatchGetFrameMetricDataResponseTypeDef:
         """
         Returns the time series of values for a requested list of frame metrics from a
         time period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.batch_get_frame_metric_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.batch_get_frame_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#batch_get_frame_metric_data)
         """
 
@@ -124,7 +124,7 @@ class CodeGuruProfilerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#can_paginate)
         """
 
@@ -132,13 +132,13 @@ class CodeGuruProfilerClient(BaseClient):
         self,
         *,
         profilingGroupName: str,
-        fleetInstanceId: str = None,
-        metadata: Dict[MetadataFieldType, str] = None
+        fleetInstanceId: str = ...,
+        metadata: Mapping[MetadataFieldType, str] = ...
     ) -> ConfigureAgentResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.configure_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#configure_agent)
         """
 
@@ -147,14 +147,14 @@ class CodeGuruProfilerClient(BaseClient):
         *,
         clientToken: str,
         profilingGroupName: str,
-        agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef" = None,
-        computePlatform: ComputePlatformType = None,
-        tags: Dict[str, str] = None
+        agentOrchestrationConfig: "AgentOrchestrationConfigTypeDef" = ...,
+        computePlatform: ComputePlatformType = ...,
+        tags: Mapping[str, str] = ...
     ) -> CreateProfilingGroupResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.create_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#create_profiling_group)
         """
 
@@ -162,7 +162,7 @@ class CodeGuruProfilerClient(BaseClient):
         """
         Deletes a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.delete_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#delete_profiling_group)
         """
 
@@ -172,31 +172,31 @@ class CodeGuruProfilerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.describe_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#describe_profiling_group)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#generate_presigned_url)
         """
 
     def get_findings_report_account_summary(
-        self, *, dailyReportsOnly: bool = None, maxResults: int = None, nextToken: str = None
+        self, *, dailyReportsOnly: bool = ..., maxResults: int = ..., nextToken: str = ...
     ) -> GetFindingsReportAccountSummaryResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_findings_report_account_summary)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_findings_report_account_summary)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_findings_report_account_summary)
         """
 
@@ -206,7 +206,7 @@ class CodeGuruProfilerClient(BaseClient):
         """
         Get the current configuration for anomaly notifications for a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_notification_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_notification_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_notification_configuration)
         """
 
@@ -214,7 +214,7 @@ class CodeGuruProfilerClient(BaseClient):
         """
         Returns the JSON-formatted resource-based policy on a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_policy)
         """
 
@@ -222,16 +222,16 @@ class CodeGuruProfilerClient(BaseClient):
         self,
         *,
         profilingGroupName: str,
-        accept: str = None,
-        endTime: Union[datetime, str] = None,
-        maxDepth: int = None,
-        period: str = None,
-        startTime: Union[datetime, str] = None
+        accept: str = ...,
+        endTime: Union[datetime, str] = ...,
+        maxDepth: int = ...,
+        period: str = ...,
+        startTime: Union[datetime, str] = ...
     ) -> GetProfileResponseTypeDef:
         """
         Gets the aggregated profile of a profiling group for a specified time range.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_profile)
         """
 
@@ -241,12 +241,12 @@ class CodeGuruProfilerClient(BaseClient):
         endTime: Union[datetime, str],
         profilingGroupName: str,
         startTime: Union[datetime, str],
-        locale: str = None
+        locale: str = ...
     ) -> GetRecommendationsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.get_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#get_recommendations)
         """
 
@@ -256,14 +256,14 @@ class CodeGuruProfilerClient(BaseClient):
         endTime: Union[datetime, str],
         profilingGroupName: str,
         startTime: Union[datetime, str],
-        dailyReportsOnly: bool = None,
-        maxResults: int = None,
-        nextToken: str = None
+        dailyReportsOnly: bool = ...,
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> ListFindingsReportsResponseTypeDef:
         """
         List the available reports for a given profiling group and time range.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_findings_reports)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_findings_reports)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_findings_reports)
         """
 
@@ -274,25 +274,25 @@ class CodeGuruProfilerClient(BaseClient):
         period: AggregationPeriodType,
         profilingGroupName: str,
         startTime: Union[datetime, str],
-        maxResults: int = None,
-        nextToken: str = None,
-        orderBy: OrderByType = None
+        maxResults: int = ...,
+        nextToken: str = ...,
+        orderBy: OrderByType = ...
     ) -> ListProfileTimesResponseTypeDef:
         """
         Lists the start times of the available aggregated profiles of a profiling group
         for an aggregation period within the specified time range.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profile_times)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_profile_times)
         """
 
     def list_profiling_groups(
-        self, *, includeDescription: bool = None, maxResults: int = None, nextToken: str = None
+        self, *, includeDescription: bool = ..., maxResults: int = ..., nextToken: str = ...
     ) -> ListProfilingGroupsResponseTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_profiling_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_profiling_groups)
         """
 
@@ -300,7 +300,7 @@ class CodeGuruProfilerClient(BaseClient):
         """
         Returns a list of the tags that are assigned to a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#list_tags_for_resource)
         """
 
@@ -310,12 +310,12 @@ class CodeGuruProfilerClient(BaseClient):
         agentProfile: Union[bytes, IO[bytes], StreamingBody],
         contentType: str,
         profilingGroupName: str,
-        profileToken: str = None
+        profileToken: str = ...
     ) -> Dict[str, Any]:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.post_agent_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#post_agent_profile)
         """
 
@@ -323,15 +323,15 @@ class CodeGuruProfilerClient(BaseClient):
         self,
         *,
         actionGroup: Literal["agentPermissions"],
-        principals: List[str],
+        principals: Sequence[str],
         profilingGroupName: str,
-        revisionId: str = None
+        revisionId: str = ...
     ) -> PutPermissionResponseTypeDef:
         """
         Adds permissions to a profiling group's resource-based policy that are provided
         using an action group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.put_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#put_permission)
         """
 
@@ -341,7 +341,7 @@ class CodeGuruProfilerClient(BaseClient):
         """
         Remove one anomaly notifications channel for a profiling group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_notification_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_notification_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#remove_notification_channel)
         """
 
@@ -351,7 +351,7 @@ class CodeGuruProfilerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.remove_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#remove_permission)
         """
 
@@ -361,28 +361,28 @@ class CodeGuruProfilerClient(BaseClient):
         anomalyInstanceId: str,
         profilingGroupName: str,
         type: FeedbackTypeType,
-        comment: str = None
+        comment: str = ...
     ) -> Dict[str, Any]:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.submit_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.submit_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#submit_feedback)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, resourceArn: str, tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Use to assign one or more tags to a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Use to remove one or more tags from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#untag_resource)
         """
 
@@ -395,7 +395,7 @@ class CodeGuruProfilerClient(BaseClient):
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Client.update_profiling_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/client.html#update_profiling_group)
         """
 
@@ -403,6 +403,6 @@ class CodeGuruProfilerClient(BaseClient):
         self, operation_name: Literal["list_profile_times"]
     ) -> ListProfileTimesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.59/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeguruprofiler/paginators.html#listprofiletimespaginator)
         """
