@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -104,7 +104,7 @@ __all__ = (
 AddNotificationChannelsRequestRequestTypeDef = TypedDict(
     "AddNotificationChannelsRequestRequestTypeDef",
     {
-        "channels": List["ChannelTypeDef"],
+        "channels": Sequence["ChannelTypeDef"],
         "profilingGroupName": str,
     },
 )
@@ -195,7 +195,7 @@ _OptionalBatchGetFrameMetricDataRequestRequestTypeDef = TypedDict(
     "_OptionalBatchGetFrameMetricDataRequestRequestTypeDef",
     {
         "endTime": Union[datetime, str],
-        "frameMetrics": List["FrameMetricTypeDef"],
+        "frameMetrics": Sequence["FrameMetricTypeDef"],
         "period": str,
         "startTime": Union[datetime, str],
         "targetResolution": AggregationPeriodType,
@@ -227,7 +227,7 @@ BatchGetFrameMetricDataResponseTypeDef = TypedDict(
 _RequiredChannelTypeDef = TypedDict(
     "_RequiredChannelTypeDef",
     {
-        "eventPublishers": List[Literal["AnomalyDetection"]],
+        "eventPublishers": Sequence[Literal["AnomalyDetection"]],
         "uri": str,
     },
 )
@@ -254,7 +254,7 @@ _OptionalConfigureAgentRequestRequestTypeDef = TypedDict(
     "_OptionalConfigureAgentRequestRequestTypeDef",
     {
         "fleetInstanceId": str,
-        "metadata": Dict[MetadataFieldType, str],
+        "metadata": Mapping[MetadataFieldType, str],
     },
     total=False,
 )
@@ -286,7 +286,7 @@ _OptionalCreateProfilingGroupRequestRequestTypeDef = TypedDict(
     {
         "agentOrchestrationConfig": "AgentOrchestrationConfigTypeDef",
         "computePlatform": ComputePlatformType,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -353,7 +353,7 @@ FrameMetricTypeDef = TypedDict(
     "FrameMetricTypeDef",
     {
         "frameName": str,
-        "threadStates": List[str],
+        "threadStates": Sequence[str],
         "type": Literal["AggregatedRelativeTotalTime"],
     },
 )
@@ -695,7 +695,7 @@ _RequiredPutPermissionRequestRequestTypeDef = TypedDict(
     "_RequiredPutPermissionRequestRequestTypeDef",
     {
         "actionGroup": Literal["agentPermissions"],
-        "principals": List[str],
+        "principals": Sequence[str],
         "profilingGroupName": str,
     },
 )
@@ -807,7 +807,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
@@ -822,7 +822,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
